<template>
  <div class="app-container">
    <div class="filter-container">
      <el-input v-model="listQuery.keyword" size="small" placeholder="请输入负责人名称/提示类型" clearable class="filter-item w-200" />
      <el-button-group class="filter-item">
        <el-button size="small" type="primary" icon="el-icon-search" @click="search">
          搜索
        </el-button>
        <el-button size="small" type="primary" icon="el-icon-refresh" @click="refresh">
          刷新
        </el-button>
        <el-button v-if="uadd=='Yes'" size="small" type="primary" icon="el-icon-plus" @click="add">
          新增
        </el-button>
      </el-button-group>
    </div>

    <el-table v-loading="listLoading" :data="list" element-loading-text="Loading" border fit height="100%"
      class="table-container" highlight-current-row>
      <el-table-column fixed label="ID" width="80" >
        <template slot-scope="scope">
          {{ scope.row.id }}
        </template>
      </el-table-column>
      <el-table-column label="提示类型" >
        <template slot-scope="scope">
          {{ scope.row.type }}
        </template>
      </el-table-column>
      <el-table-column label="负责人" >
        <template slot-scope="scope">
          {{ scope.row.manager }}
        </template>
      </el-table-column>
      <el-table-column label="负责人电话" >
        <template slot-scope="scope">
          {{ scope.row.phone }}
        </template>
      </el-table-column>
      <!-- <el-table-column label="负责人部门" >
        <template slot-scope="scope">
          {{ scope.row.bumen }}
        </template>
      </el-table-column> -->
      <el-table-column label="提示短信" >
        <template slot-scope="scope">
          {{ scope.row.duanxin }}
        </template>
      </el-table-column>
      <el-table-column label="添加时间"  width="180">
        <template slot-scope="scope">
          {{ scope.row.addtime }}
        </template>
      </el-table-column>
      <el-table-column  label="操作" width="200"  v-if="uupdate=='Yes' || udelete=='Yes'">
        <template slot-scope="scope">
          <el-button-group>
            <el-button v-if="uupdate=='Yes'" type="primary" icon="el-icon-edit" size="mini" @click="edit(scope)">
              修改
            </el-button>
            <el-button v-if="udelete=='Yes'" type="danger" icon="el-icon-delete" size="mini" @click="del(scope)">
              删除
            </el-button>
          </el-button-group>
        </template>
      </el-table-column>
    </el-table>

    <pagination v-show="total > 0" :total="total" :page.sync="listQuery.current" :limit.sync="listQuery.size"
      @pagination="fetchData" />

    <el-dialog :visible.sync="dialogVisible" :title="dialogType === 'modify' ? '修改' : '新增'">
      <el-form :ref="temp" :model="temp" label-width="120px" label-position="right" :rules="rules">
        <el-form-item label="提示类型" prop="type">
          <el-select style="width: 100%;" v-model="temp.type" placeholder="请选择">
            <el-option v-for="item in options" :key="item.value" :label="item.label" :value="item.value">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="负责人" prop="manager">
          <el-input v-model="temp.manager
        " placeholder="请输入负责人" />
        </el-form-item>
        <el-form-item label="负责人电话" prop="phone">
          <el-input v-model="temp.phone
        " placeholder="请输入负责人电话" />
        </el-form-item>
        <!-- <el-form-item label="负责人部门" prop="bumen">
          <el-select style="width: 100%;" v-model="temp.bumen" placeholder="请选择">
            <el-option v-for="item in bumenoptions" :key="item.value" :label="item.label" :value="item.value">
            </el-option>
          </el-select>
        </el-form-item> -->
        <el-form-item label="提示短信" prop="duanxin">
          <el-input type="textarea" :autosize="{ minRows: 2, maxRows: 4 }" placeholder="请输入提示短信" v-model="temp.duanxin">
          </el-input>
          <!-- <el-input v-model="temp.duanxin
        " placeholder="请输入提示短信" /> -->
        </el-form-item>
      </el-form>
      <div class="text-right">
        <el-button type="danger" @click="dialogVisible = false">
          取消
        </el-button>
        <el-button type="primary" @click="submit">
          确定
        </el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import Pagination from '@/components/Pagination'
import { getDuanxinPage, delDuanxin, addorupDuanxin, searchDuanxin, getVoicetip, getbumen,addSystemOperationLog } from '@/api/duanxin'
import { deepClone } from '@/utils'

const _temp = {
  id: '',
  type: '',
  bumen: '',
  manager: '',
  phone: '',
  duanxin:'',
}

export default {
  components: {
    Pagination
  },
  data() {
    return {
      uadd:'',
      udelete:'',
      uupdate:'',
      bumenoptions: [],
      options: [],
      total: 0,
      list: [],
      menus: [],
      listLoading: true,
      listQuery: {
        current: 1,
        size: 20,
        keyword: undefined,
      },
      uploadUrl: '',
      temp: Object.assign({}, _temp),
      dialogVisible: false,
      dialogType: 'create',
      loading: false,
      rules: {
        type: [
            { required: true, message: '请选择提示类型', trigger: 'blur' },
          ],
          bumen: [
            { required: true, message: '请选择部门', trigger: 'blur' }
          ],
          manager: [
            {  required: true, message: '请输入负责人', trigger: 'change' }
          ],
          phone: [
            {  required: true, message: '请输入负责人电话', trigger: 'blur' }
          ],
          duanxin: [
            {  required: true, message: '请输入提示短信', trigger: 'blur' }
          ]
        },
    }
  },
  created() {
    this.fetchData()
  },
  methods: {
    // 搜索
    search() {
      this.listLoading = true
      searchDuanxin(this.listQuery).then(response => {
        if (response.data!=null) {
          this.list = response.data.records
          this.total = response.data.total
        }else{
          this.$message({
            message: '未搜索到数据',
            type: 'error'
          })
        }
      
        this.listLoading = false
      })
    },
    refresh() {
      this.listQuery = {
        current: 1,
        size: 20,
        keyword: undefined
      }
      this.fetchData()
    },
    // 分页数据
    fetchData() {
      this.uadd = localStorage.getItem('uadd') || '';
      this.udelete = localStorage.getItem('udelete') || '';
      this.uupdate = localStorage.getItem('uupdate') || '';
      this.listLoading = true
      getDuanxinPage(this.listQuery).then(response => {
        this.list = response.data.records
        this.total = response.data.total
        this.listLoading = false
      })
      this.options=[]
      getVoicetip().then(response => {
        for (let index = 0; index < response.data.length; index++) {
          var json = {
            value: '',
            label: '',
          }
          const element = response.data[index];
          json.value = element
          json.label = element
          this.options.push(json)
        }

      })
      this.bumenoptions=[]
      getbumen().then(response => {
        for (let index = 0; index < response.data.length; index++) {
          const element = response.data[index];
          var bumenjson = {
            value: '',
            label: '',
          }
          bumenjson.value = element
          bumenjson.label = element
          this.bumenoptions.push(bumenjson)
        }

      })


    },
    resetTemp() {
      this.temp = Object.assign({}, _temp)
    },
    add() {
      this.resetTemp()
      this.dialogVisible = true
      this.dialogType = 'create'
      // this.$nextTick(() => {
      //   this.$refs['dataForm'].clearValidate()
      // })
    },
    edit(scope) {
      this.resetTemp()
      this.dialogVisible = true
      this.dialogType = 'modify'
      this.temp = deepClone(scope.row)
      // this.$nextTick(() => {
      //   this.$refs['dataForm'].clearValidate()
      // })
    },
    changeStatus(value, scope) {
      setTimeout(() => {
        this.list[scope.$index].status = value
        this.$message({
          message: '更新成功',
          type: 'success'
        })
      }, 300)
    },
    // 删除
    del(scope) {
      this.$confirm('确认删除该条数据吗？', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        setTimeout(() => {
          const params = { id: scope.row.id };
          this.list.splice(scope.$index, 1)
          delDuanxin(params).then(response => {
            this.temp.adminname = localStorage.getItem('username') || '';
            const params = { name:  this.temp.adminname, content: '删除了一个短信提示，该提示类型为：'+scope.row.type };
            addSystemOperationLog(params).then(response => {

                        })
            this.$message({
              message: '删除成功',
              type: 'success'
            })
            this.fetchData()
          })
        }, 300)
      })
    },
    submit() {
      if (this.loading) {
        return
      }
      this.loading = true
      this.$refs[this.temp].validate((valid) => {
        if (valid) {
      addorupDuanxin(this.temp).then(() => {
        if (this.temp.id=="") {
          this.temp.adminname = localStorage.getItem('username') || '';
            const params = { name:  this.temp.adminname, content: '新增了一个短信提示，该提示类型为：'+this.temp.type };
            addSystemOperationLog(params).then(response => {

                        })
        } else {
          this.temp.adminname = localStorage.getItem('username') || '';
            const params = { name:  this.temp.adminname, content: '修改了一个短信提示，该提示类型为：'+this.temp.type };
            addSystemOperationLog(params).then(response => {

                        })
        }
        this.fetchData()
        setTimeout(() => {
          this.$message({
            message: '提交成功',
            type: 'success'
          })
          this.dialogVisible = false
          this.loading = false
        }, 300)
      })

    } else {
            this.$message({
            message: '提交失败，请检查表单必填项是否为空',
            type: 'error'
          })
            console.log('error submit!!');
            return false;
          }
        });
    }
  }
}
</script>

<style lang="scss" scoped>
.el-upload {
  border: 1px dashed #d9d9d9 !important;
  border-radius: 6px;
  cursor: pointer;
  position: relative;
  overflow: hidden;

  .el-icon-plus.avatar-uploader-icon {
    border: 1px dashed #d9d9d9 !important;
    border-radius: 6px;
    font-size: 28px;
    color: #8c939d;
    width: 128px;
    height: 128px;
    line-height: 128px;
    text-align: center;
  }
}

.avatar-uploader {
  height: 128px;

  img {
    width: 128px;
    height: 128px;
  }
}
</style>
